@@ -8,49 +8,39 @@ License BSD, see LICENSE for more details.
 
 from __future__ import print_function
 
-import abc
 import base64
 import hashlib
 import hmac
 
-from Crypto import Hash
-from Crypto import Random
 from Crypto.Cipher import AES
 from Crypto.Protocol import KDF
 
+from .utils import bchr, bord, to_bytes, to_str
+
 
 class CryptorException(Exception):
     pass
 
 
-class Cryptor(object):
-    __metaclass__ = abc.ABCMeta
-
-    @abc.abstractmethod
-    def decrypt(self, data, password):
-        return data
-
-    @abc.abstractmethod
-    def encrypt(self, data, password):
-        return data
-
-
-class RNCryptor(Cryptor):
+class RNCryptor(object):
 
     AES_BLOCK_SIZE = AES.block_size
     AES_MODE = AES.MODE_CBC
     SALT_SIZE = 8
 
     def pre_decrypt_data(self, data):
+        data = to_bytes(data)
         return base64.decodestring(data)
 
     def post_decrypt_data(self, data):
         """ Removes useless symbols which appear over padding for AES (PKCS#7). """
 
-        return data[:-ord(data[-1])]
+        data = data[:-bord(data[-1])]
+        return to_str(data)
 
     def decrypt(self, data, password):
         data = self.pre_decrypt_data(data)
+        password = to_bytes(password)
 
         n = len(data)
 
@@ -75,14 +65,17 @@ class RNCryptor(Cryptor):
     def pre_encrypt_data(self, data):
         """ Does padding for the data for AES (PKCS#7). """
 
+        data = to_bytes(data)
         rem = self.AES_BLOCK_SIZE - len(data) % self.AES_BLOCK_SIZE
-        return data + chr(rem) * rem
+        return data + bchr(rem) * rem
 
     def post_encrypt_data(self, data):
-        return base64.encodestring(data)
+        data = base64.encodestring(data)
+        return to_str(data)
 
     def encrypt(self, data, password):
         data = self.pre_encrypt_data(data)
+        password = to_bytes(password)
 
         encryption_salt = self.encryption_salt
         encryption_key = self._pbkdf2(password, encryption_salt)
@@ -111,12 +104,11 @@ class RNCryptor(Cryptor):
 
     @property
     def hmac_salt(self):
-        Random.atfork()
-        return Random.new().read(self.SALT_SIZE)
+        return self._hmac_salt
 
     @hmac_salt.setter
     def hmac_salt(self, value):
-        raise NotImplementedError()
+        self._hmac_salt = value
 
     @property
     def iv(self):
@@ -133,11 +125,13 @@ class RNCryptor(Cryptor):
         return AES.new(key, self.AES_MODE, iv).decrypt(text)
 
     def _hmac(self, key, data):
-        return Hash.HMAC.new(key, data, Hash.SHA256).digest()
+        return hmac.new(key, data, hashlib.sha256).digest()
 
     def _pbkdf2(self, password, salt, iterations=10000, key_length=32):
-        return KDF.PBKDF2(password, salt, dkLen=key_length, count=iterations,
-                          prf=lambda p, s: hmac.new(p, s, hashlib.sha1).digest())
+        if not getattr(self, '_key', None):
+            self._key = KDF.PBKDF2(password, salt, dkLen=key_length, count=iterations,
+                                   prf=lambda p, s: hmac.new(p, s, hashlib.sha1).digest())
+        return self._key
 
         ## django 1.5 version -- faster than crypto version
         # import hashlib
@@ -154,6 +148,7 @@ def main():
 
     cryptor = RNCryptor()
     cryptor.encryption_salt = b'1' * 8
+    cryptor.hmac_salt = b'1' * 8
     cryptor.iv = b'2' * 16
 
     passwords = 'p@s$VV0Rd', 'пароль'
