@@ -13,7 +13,7 @@ from serverauditor_sshconfig.core.api import API
 from serverauditor_sshconfig.core.cryptor import RNCryptor
 from serverauditor_sshconfig.core.logger import PrettyLogger
 from serverauditor_sshconfig.core.ssh_config import SSHConfig
-from serverauditor_sshconfig.core.utils import parallel_map
+from serverauditor_sshconfig.core.utils import parallel_map, p_input
 
 
 class ExportSSHConfigApplication(SSHConfigApplication):
@@ -74,24 +74,29 @@ class ExportSSHConfigApplication(SSHConfigApplication):
         return
 
     def _choose_new_hosts(self):
+        def get_prompt():
+            if self._local_hosts:
+                return "You may confirm this list (press 'Enter'), add (enter '+') or remove (enter its number) host: "
+            else:
+                return "You may confirm this list (press 'Enter') or add (enter '+') host: "
+
         def get_hosts_names():
             return ', '.join('%s (#%d)' % (h, i) for i, h in enumerate(self._local_hosts)) or '[]'
 
         self._logger.log("The following new hosts have been founded in your ssh config:", sleep=0)
         self._logger.log(get_hosts_names(), color='blue')
 
-        prompt = "You may confirm this list (press 'Enter'), add (enter '+') or remove (enter its number) host: "
         while True:
-            number = raw_input(prompt).strip()
+            number = p_input(get_prompt()).strip()
 
             if number == '':
                 break
 
             if number == '+':
-                host = raw_input("Enter host: ")
+                host = p_input("Enter host: ")
                 conf = self._config.get_host(host)
-                if conf.keys() == ['host']:
-                    self._logger.log("There is no config for host %s!" % host, file=sys.stderr)
+                if list(conf.keys()) == ['host']:
+                    self._logger.log("There is no config for host %s!" % host, color='red', file=sys.stderr)
                 else:
                     self._local_hosts.append(host)
 
