@@ -15,6 +15,7 @@ from serverauditor_sshconfig.core.api import API
 from serverauditor_sshconfig.core.cryptor import RNCryptor
 from serverauditor_sshconfig.core.logger import PrettyLogger
 from serverauditor_sshconfig.core.ssh_config import SSHConfig
+from serverauditor_sshconfig.core.utils import p_input
 
 
 class ImportSSHConfigApplication(SSHConfigApplication):
@@ -83,7 +84,8 @@ Host {host}
             return '%s (#%d)' % (name, number)
 
         def get_connections_names():
-            return ', '.join(get_connection_name(c, i) for i, c in enumerate(self._sa_connections)) or '[]'
+            return (', '.join(get_connection_name(c, i) for i, c in enumerate(self._sa_connections))
+                    or 'There are no more connections!')
 
         if not self._sa_connections:
             self._logger.log("There are no new connections on ServerAuditor's servers.")
@@ -94,8 +96,8 @@ Host {host}
         self._logger.log(get_connections_names(), color='blue')
 
         prompt = "You may confirm this list (press 'Enter') or remove host (enter its number): "
-        while True:
-            number = raw_input(prompt).strip()
+        while len(self._sa_connections):
+            number = p_input(prompt).strip()
 
             if number == '':
                 break
@@ -118,6 +120,11 @@ Host {host}
 
     @description("Creating keys and connections...")
     def _create_keys_and_connections(self):
+        def get_param_name(s):
+            if any(c.isspace() for c in s):
+                return '"%s"' % s
+            return s
+
         def check_ssh_keys_dir():
             key_dir = os.path.expanduser(self.SSH_KEYS_DIR)
             if not os.path.exists(key_dir):
@@ -135,17 +142,17 @@ Host {host}
 
             with open(self._config.USER_CONFIG_PATH, 'a') as cf:
                 host = self.SSH_CONFIG_HOST_TEMPLATE.format(
-                    host=conn['label'] or conn['hostname'],
-                    hostname=conn['hostname'],
-                    port=conn['port'],
-                    user=conn['ssh_username']
+                    host=get_param_name(conn['label'] or conn['hostname']),
+                    hostname=get_param_name(conn['hostname']),
+                    user=get_param_name(conn['ssh_username']),
+                    port=conn['port']
                 )
                 cf.write(host)
 
                 if conn['ssh_key']:
                     key = self._sa_keys[conn['ssh_key']['id']]
                     key_name = get_key_path(key)
-                    idf = self.SSH_CONFIG_HOST_IDENTITY_FILE.format(key=key_name)
+                    idf = self.SSH_CONFIG_HOST_IDENTITY_FILE.format(key=get_param_name(key_name))
                     cf.write(idf)
 
                 cf.write('\n')
